@@ -122,6 +122,8 @@ int main (int argc, char *argv[])
 				flags |= 4;
 			}else if (strcmp(opt,"private")==0){
 				flags |= 8;
+			}else if (strcmp(opt,"hideinfo")==0){
+				flags |= 32;
 			}else{
 				fprintf (stderr,"Unknown flag %s\n",opt);
 			}
