@@ -91,6 +91,12 @@ int vbuild_mkdir (const char *path, mode_t mode)
 		ret = 0;
 	}else{
 		ret = mkdir (path,mode);
+		if (ret == -1 && errno == EEXIST){
+			struct stat st;
+			if (lstat(path,&st)!=-1	&& S_ISDIR(st.st_mode)){
+				ret = chmod (path,mode);
+			}
+		}
 	}
 	return ret;
 }
@@ -103,6 +109,15 @@ int vbuild_mknod(const char *path, mode_t mode, dev_t dev)
 		ret = 0;
 	}else{
 		ret = mknod (path,mode,dev);
+		if (ret == -1 && errno == EEXIST){
+			struct stat st;
+			lstat(path,&st);
+			if (lstat(path,&st)!=-1
+				&& (st.st_mode & S_IFMT) == (mode & S_IFMT)
+				&& st.st_rdev == dev){
+				ret = chmod (path,mode);
+			}
+		}
 	}
 	return ret;
 }
